# -*- coding: utf-8 -*-
# encoding: utf-8

# Gravaty
# Copyright © 2013  Marco Bresciani
#
# This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with this program. If not, see
# <http://www.gnu.org/licenses/>.

require 'digest/md5'

class Gravaty
  attr_reader :email, :digest

  BASIC_URL = 'http://www.gravatar.com/avatar/'
  SIZE_RANGE = (1...2048)
  MIN_SIZE = 1
  MAX_SIZE = 2048

  def initialize(email)
    @email = email
    @digest = Digest::MD5.hexdigest @email.downcase
  end

  def basic_url(type = nil)
    extension = ''
    case type.downcase
      when 'jpg', 'jpeg', 'png'
        extension = '.' + type.downcase
      else
        raise ArgumentError, t('Type_Error')
    end if not type.nil?
    BASIC_URL + @digest + extension
  end

  def size_url(value)
    raise ArgumentError, t('Value_Error') if !value.to_i.between?(MIN_SIZE, MAX_SIZE)
    basic_url + '?s=' + value
  end
end
